@@ -236,7 +236,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_OVERBURN|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	/* This is a CDR with data data can be merged or at least appended */	\
 	brasero_plugin_set_flags (plugin_MACRO,					\
@@ -252,7 +252,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_APPEND);
 
 #define BRASERO_PLUGIN_ADD_STANDARD_CDRW_FLAGS(plugin_MACRO, unsupported_MACRO)			\
@@ -267,7 +267,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_OVERBURN|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	/* It is a CDRW we want the CD to be either blanked before or appended	\
 	 * that's why we set MERGE as compulsory. That way if the CD is not 	\
@@ -286,7 +286,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MERGE);
 
 #define BRASERO_PLUGIN_ADD_STANDARD_DVDR_FLAGS(plugin_MACRO, unsupported_MACRO)			\
@@ -300,7 +300,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_BURNPROOF|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_DVDR|				\
@@ -311,7 +311,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	/* This is a DVDR with data; data can be merged or at least appended */	\
 	brasero_plugin_set_flags (plugin_MACRO,					\
@@ -326,7 +326,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_APPEND);
 
 #define BRASERO_PLUGIN_ADD_STANDARD_DVDR_PLUS_FLAGS(plugin_MACRO, unsupported_MACRO)		\
@@ -338,7 +338,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  (BRASERO_BURN_FLAG_DAO|			\
 				  BRASERO_BURN_FLAG_BURNPROOF|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_DVDR_PLUS|			\
@@ -347,7 +347,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  (BRASERO_BURN_FLAG_BURNPROOF|			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	/* DVD+R with data: data can be merged or at least appended */		\
 	brasero_plugin_set_flags (plugin_MACRO,					\
@@ -360,7 +360,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_BURNPROOF|			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_APPEND);
 
 #define BRASERO_PLUGIN_ADD_STANDARD_DVDRW_FLAGS(plugin_MACRO, unsupported_MACRO)			\
@@ -372,7 +372,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_BURNPROOF|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_DVDRW|				\
@@ -381,7 +381,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	/* This is a DVDRW we want the DVD to be either blanked before or	\
 	 * appended that's why we set MERGE as compulsory. That way if the DVD	\
@@ -397,7 +397,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MERGE);
 
 /**
@@ -416,7 +416,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_MEDIUM_BLANK,				\
 				  (BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MULTI);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_DVDRW_PLUS|			\
@@ -427,7 +427,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  (BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE|			\
 				  BRASERO_BURN_FLAG_MERGE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MULTI);
 
 /**
@@ -443,7 +443,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_MEDIUM_BLANK,				\
 				  (BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MULTI);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_DVD|				\
@@ -455,7 +455,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  (BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE|			\
 				  BRASERO_BURN_FLAG_MERGE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MULTI);
 
 #define BRASERO_PLUGIN_ADD_STANDARD_BD_R_FLAGS(plugin_MACRO, unsupported_MACRO)			\
@@ -469,7 +469,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  (BRASERO_BURN_FLAG_DAO|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_BDR_RANDOM|			\
@@ -480,7 +480,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_NONE);			\
 	/* This is a DVDR with data data can be merged or at least appended */	\
 	brasero_plugin_set_flags (plugin_MACRO,					\
@@ -495,7 +495,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_DUMMY|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_APPEND);
 
 /**
@@ -514,7 +514,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  BRASERO_MEDIUM_BLANK,				\
 				  (BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MULTI);			\
 	brasero_plugin_set_flags (plugin_MACRO,					\
 				  BRASERO_MEDIUM_BDRE|				\
@@ -525,7 +525,7 @@ brasero_plugin_register (BraseroPlugin *plugin, gchar **error)			\
 				  (BRASERO_BURN_FLAG_MULTI|			\
 				  BRASERO_BURN_FLAG_NOGRACE|			\
 				  BRASERO_BURN_FLAG_MERGE) &			\
-				  (~unsupported_MACRO),				\
+				  (~(unsupported_MACRO)),				\
 				  BRASERO_BURN_FLAG_MULTI);
 
 G_END_DECLS
