@@ -41,6 +41,7 @@
 #include <gtk/gtk.h>
 
 #include "brasero-units.h"
+#include "brasero-volume.h"
 
 #include "brasero-track-data-cfg.h"
 
@@ -61,7 +62,7 @@ struct _BraseroTrackDataCfgPrivate
 
 	BraseroFileNode *autorun;
 	BraseroFileNode *icon;
-	gchar *image_path;
+	GFile *image_file;
 
 	BraseroDataTreeModel *tree;
 	guint stamp;
@@ -225,7 +226,7 @@ brasero_track_data_cfg_nth_child (BraseroFileNode *parent,
 				  guint nth)
 {
 	BraseroFileNode *peers;
-	guint pos;
+	gint pos;
 
 	if (!parent)
 		return NULL;
@@ -235,11 +236,11 @@ brasero_track_data_cfg_nth_child (BraseroFileNode *parent,
 		peers = peers->next;
 		
 	for (pos = 0; pos < nth && peers; pos ++) {
-		/* Don't include hidden */
-		if (peers->is_hidden)
-			pos --;
-
 		peers = peers->next;
+
+		/* Skip hidden */
+		while (peers && peers->is_hidden)
+			peers = peers->next;
 	}
 
 	return peers;
@@ -385,14 +386,22 @@ brasero_track_data_cfg_iter_children (GtkTreeModel *model,
 
 	if (!parent) {
 		BraseroFileNode *root;
+		BraseroFileNode *node;
 
 		/* This is for the top directory */
 		root = brasero_data_project_get_root (BRASERO_DATA_PROJECT (priv->tree));
-		if (!root || !brasero_track_data_cfg_get_n_children (root))
+		if (!root)
 			return FALSE;
 
+		node = BRASERO_FILE_NODE_CHILDREN (root);
+		while (node && node->is_hidden)
+			node = node->next;
+
+		if (!node || node->is_hidden)
+			return FALSE;
+
+		iter->user_data = node;
 		iter->stamp = priv->stamp;
-		iter->user_data = BRASERO_FILE_NODE_CHILDREN (root);
 		iter->user_data2 = GINT_TO_POINTER (BRASERO_ROW_REGULAR);
 		return TRUE;
 	}
@@ -449,10 +458,16 @@ brasero_track_data_cfg_iter_next (GtkTreeModel *model,
 	}
 
 	node = iter->user_data;
-	iter->user_data = node->next;
-	if (!node->next || node->next->is_hidden)
+	node = node->next;
+
+	/* skip all hidden files */
+	while (node && node->is_hidden)
+		node = node->next;
+
+	if (!node || node->is_hidden)
 		return FALSE;
 
+	iter->user_data = node;
 	return TRUE;
 }
 
@@ -639,7 +654,10 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 	
 		case BRASERO_DATA_TREE_MODEL_COLOR:
 			g_value_init (value, G_TYPE_STRING);
-			g_value_set_string (value, NULL);
+			if (node->is_imported)
+				g_value_set_string (value, "grey50");
+			else
+				g_value_set_string (value, NULL);
 			return;
 
 		case BRASERO_DATA_TREE_MODEL_IS_FILE:
@@ -906,7 +924,7 @@ brasero_track_data_cfg_get_path (GtkTreeModel *model,
 	return path;
 }
 
-BraseroFileNode *
+static BraseroFileNode *
 brasero_track_data_cfg_path_to_node (BraseroTrackDataCfg *self,
 				     GtkTreePath *path)
 {
@@ -1351,6 +1369,9 @@ brasero_track_data_cfg_autorun_inf_parse (BraseroTrackDataCfg *track,
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
 
+	if (!uri)
+		return FALSE;
+
 	path = g_filename_from_uri (uri, NULL, NULL);
 	key_file = g_key_file_new ();
 
@@ -1429,13 +1450,18 @@ brasero_track_data_cfg_node_added (BraseroDataProject *project,
 		if (!strcasecmp (BRASERO_FILE_NODE_NAME (node), "autorun.inf")) {
 			gchar *uri;
 
+			
 			/* This has been added by the user or by a project so
 			 * we do display it; also we signal the change in icon.
 			 * NOTE: if we had our own autorun.inf it was wiped out
 			 * in the callback for "name-collision". */
 			uri = brasero_data_project_node_to_uri (BRASERO_DATA_PROJECT (priv->tree), node);
-			priv->icon = brasero_track_data_cfg_autorun_inf_parse (self, uri);
-			g_free (uri);
+			if (!uri) {
+				/* URI can be NULL sometimes if the autorun.inf is from
+				 * the session of the imported medium */
+				priv->icon = brasero_track_data_cfg_autorun_inf_parse (self, uri);
+				g_free (uri);
+			}
 
 			g_signal_emit (self,
 				       brasero_track_data_cfg_signals [ICON_CHANGED],
@@ -1507,6 +1533,28 @@ brasero_track_data_cfg_node_added (BraseroDataProject *project,
 //		node->is_visible = TRUE;
 }
 
+static guint
+brasero_track_data_cfg_convert_former_position (BraseroFileNode *former_parent,
+                                                guint former_position)
+{
+	BraseroFileNode *child;
+	guint hidden_num = 0;
+	guint current_pos;
+
+	/* We need to convert former_position to the right position in the
+	 * treeview as there could be some hidden node before this position. */
+	child = BRASERO_FILE_NODE_CHILDREN (former_parent);
+
+	for (current_pos = 0; child && current_pos != former_position; current_pos ++) {
+		if (child->is_hidden)
+			hidden_num ++;
+
+		child = child->next;
+	}
+
+	return former_position - hidden_num;
+}
+
 static void
 brasero_track_data_cfg_node_removed (BraseroDataProject *project,
 				     BraseroFileNode *former_parent,
@@ -1575,7 +1623,7 @@ brasero_track_data_cfg_node_removed (BraseroDataProject *project,
 	/* remove the node. Do it after adding a possible BOGUS row.
 	 * NOTE since BOGUS row has been added move row. */
 	path = brasero_track_data_cfg_node_to_path (self, former_parent);
-	gtk_tree_path_append_index (path, former_position);
+	gtk_tree_path_append_index (path, brasero_track_data_cfg_convert_former_position (former_parent, former_position));
 
 	gtk_tree_model_row_deleted (GTK_TREE_MODEL (self), path);
 	gtk_tree_path_free (path);
@@ -1678,9 +1726,9 @@ brasero_track_data_clean_autorun (BraseroTrackDataCfg *track)
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
 
-	if (priv->image_path) {
-		g_free (priv->image_path);
-		priv->image_path = NULL;
+	if (priv->image_file) {
+		g_object_unref (priv->image_file);
+		priv->image_file = NULL;
 	}
 
 	if (priv->autorun) {
@@ -1705,29 +1753,6 @@ brasero_track_data_clean_autorun (BraseroTrackDataCfg *track)
 		priv->icon = NULL;
 }
 
-static void
-brasero_track_data_cfg_finalize (GObject *object)
-{
-	BraseroTrackDataCfgPrivate *priv;
-
-	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (object);
-
-	brasero_track_data_clean_autorun (BRASERO_TRACK_DATA_CFG (object));
-	brasero_track_data_cfg_clean_cache (BRASERO_TRACK_DATA_CFG (object));
-
-	if (priv->shown) {
-		g_slist_free (priv->shown);
-		priv->shown = NULL;
-	}
-
-	if (priv->tree) {
-		g_object_unref (priv->tree);
-		priv->tree = NULL;
-	}
-
-	G_OBJECT_CLASS (brasero_track_data_cfg_parent_class)->finalize (object);
-}
-
 static void
 brasero_track_data_cfg_iface_init (gpointer g_iface, gpointer data)
 {
@@ -1807,6 +1832,20 @@ brasero_track_data_cfg_sortable_iface_init (gpointer g_iface, gpointer data)
  * Track part
  */
 
+/**
+ * brasero_track_data_cfg_add:
+ * @track: a #BraseroTrackDataCfg
+ * @uri: a #gchar
+ * @parent: a #GtkTreePath or NULL
+ *
+ * Add a new file (with @uri as URI) under a directory (@parent).
+ * If @parent is NULL, the file is added to the root.
+ * Also if @uri is the path of a directory, this directory will be explored
+ * and all its children added to the tree.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successful, FALSE otherwise
+ **/
+
 gboolean
 brasero_track_data_cfg_add (BraseroTrackDataCfg *track,
 			    const gchar *uri,
@@ -1832,6 +1871,18 @@ brasero_track_data_cfg_add (BraseroTrackDataCfg *track,
 	return (brasero_data_project_add_loading_node (BRASERO_DATA_PROJECT (BRASERO_DATA_PROJECT (priv->tree)), uri, parent_node) != NULL);
 }
 
+/**
+ * brasero_track_data_cfg_add_empty_directory:
+ * @track: a #BraseroTrackDataCfg
+ * @name: a #gchar
+ * @parent: a #GtkTreePath or NULL
+ *
+ * Add a new empty directory (with @name as name) under another directory (@parent).
+ * If @parent is NULL, the file is added to the root.
+ *
+ * Return value: a #GtkTreePath which should be destroyed when not needed; NULL if the operation was not successful.
+ **/
+
 GtkTreePath *
 brasero_track_data_cfg_add_empty_directory (BraseroTrackDataCfg *track,
 					    const gchar *name,
@@ -1886,6 +1937,17 @@ brasero_track_data_cfg_add_empty_directory (BraseroTrackDataCfg *track,
 	return path;
 }
 
+/**
+ * brasero_track_data_cfg_remove:
+ * @track: a #BraseroTrackDataCfg
+ * @treepath: a #GtkTreePath
+ *
+ * Removes a file or a directory (as well as its children) from the tree.
+ * NOTE: some files cannot be removed like files from an imported session.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successful, FALSE otherwise
+ **/
+
 gboolean
 brasero_track_data_cfg_remove (BraseroTrackDataCfg *track,
 			       GtkTreePath *treepath)
@@ -1903,6 +1965,17 @@ brasero_track_data_cfg_remove (BraseroTrackDataCfg *track,
 	return TRUE;
 }
 
+/**
+ * brasero_track_data_cfg_rename:
+ * @track: a #BraseroTrackDataCfg
+ * @newname: a #gchar
+ * @treepath: a #GtkTreePath
+ *
+ * Renames the file in the tree pointed by @treepath.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successful, FALSE otherwise
+ **/
+
 gboolean
 brasero_track_data_cfg_rename (BraseroTrackDataCfg *track,
 			       const gchar *newname,
@@ -1919,6 +1992,15 @@ brasero_track_data_cfg_rename (BraseroTrackDataCfg *track,
 						 newname);
 }
 
+/**
+ * brasero_track_data_cfg_reset:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Completely empties @track and unloads any currently loaded session
+ *
+ * Return value: a #gboolean. TRUE if the operation was successful, FALSE otherwise
+ **/
+
 gboolean
 brasero_track_data_cfg_reset (BraseroTrackDataCfg *track)
 {
@@ -1959,6 +2041,16 @@ brasero_track_data_cfg_reset (BraseroTrackDataCfg *track)
 	return TRUE;
 }
 
+/**
+ * brasero_track_data_cfg_get_filtered_model:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Gets a GtkTreeModel which contains all the files that were
+ * automatically filtered while added directories were explored.
+ *
+ * Return value: a #GtkTreeModel. Unref when not needed.
+ **/
+
 GtkTreeModel *
 brasero_track_data_cfg_get_filtered_model (BraseroTrackDataCfg *track)
 {
@@ -1972,6 +2064,18 @@ brasero_track_data_cfg_get_filtered_model (BraseroTrackDataCfg *track)
 	return model;
 }
 
+/**
+ * brasero_track_data_cfg_restore:
+ * @track: a #BraseroTrackDataCfg
+ * @treepath: a #GtkTreePath
+ *
+ * Removes a file from the filtered file list (see brasero_track_data_cfg_get_filtered_model ())
+ * and re-adds it wherever it should be in the tree.
+ * @treepath is a #GtkTreePath associated with the #GtkTreeModel which holds the
+ * filtered files not the main tree.
+ *
+ **/
+
 void
 brasero_track_data_cfg_restore (BraseroTrackDataCfg *track,
 				GtkTreePath *treepath)
@@ -1990,6 +2094,16 @@ brasero_track_data_cfg_restore (BraseroTrackDataCfg *track,
 	g_free (uri);
 }
 
+/**
+ * brasero_track_data_cfg_dont_filter_uri:
+ * @track: a #BraseroTrackDataCfg
+ * @uri: a #gchar
+ *
+ * Prevents @uri to be filtered while automatic exploration
+ * of added directories is performed.
+ *
+ **/
+
 void
 brasero_track_data_cfg_dont_filter_uri (BraseroTrackDataCfg *track,
 					const gchar *uri)
@@ -2005,6 +2119,15 @@ brasero_track_data_cfg_dont_filter_uri (BraseroTrackDataCfg *track,
 	brasero_data_project_restore_uri (BRASERO_DATA_PROJECT (priv->tree), uri);
 }
 
+/**
+ * brasero_track_data_cfg_get_restored_list:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Gets a list of URIs (as #gchar *) that were restored with brasero_track_data_cfg_restore ().
+ *
+ * Return value: a #GSList; free the list and its contents when not needed anymore.
+ **/
+
 GSList *
 brasero_track_data_cfg_get_restored_list (BraseroTrackDataCfg *track)
 {
@@ -2018,6 +2141,19 @@ brasero_track_data_cfg_get_restored_list (BraseroTrackDataCfg *track)
 	return brasero_filtered_uri_get_restored_list (filtered);
 }
 
+/**
+ * brasero_track_data_cfg_load_medium:
+ * @track: a #BraseroTrackDataCfg
+ * @medium: a #BraseroMedium
+ * @error: a #GError
+ *
+ * Tries to load the contents of the last session of @medium so all its files will be included in the tree
+ * to perform a merge between files from the session and new added files.
+ * Errors are stored in @error.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successful, FALSE otherwise
+ **/
+
 gboolean
 brasero_track_data_cfg_load_medium (BraseroTrackDataCfg *track,
 				    BraseroMedium *medium,
@@ -2032,6 +2168,15 @@ brasero_track_data_cfg_load_medium (BraseroTrackDataCfg *track,
 					      error);
 }
 
+/**
+ * brasero_track_data_cfg_unload_current_medium:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Unload the contents of the last session of the currently loaded medium.
+ * See brasero_track_data_cfg_load_medium ().
+ *
+ **/
+
 void
 brasero_track_data_cfg_unload_current_medium (BraseroTrackDataCfg *track)
 {
@@ -2042,6 +2187,16 @@ brasero_track_data_cfg_unload_current_medium (BraseroTrackDataCfg *track)
 	brasero_data_session_remove_last (BRASERO_DATA_SESSION (priv->tree));
 }
 
+/**
+ * brasero_track_data_cfg_get_current_medium:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Gets the currently loaded medium.
+ *
+ * Return value: a #BraseroMedium. NULL if no medium are currently loaded.
+ * Do not unref when the #BraseroMedium is not needed anymore.
+ **/
+
 BraseroMedium *
 brasero_track_data_cfg_get_current_medium (BraseroTrackDataCfg *track)
 {
@@ -2052,6 +2207,15 @@ brasero_track_data_cfg_get_current_medium (BraseroTrackDataCfg *track)
 	return brasero_data_session_get_loaded_medium (BRASERO_DATA_SESSION (priv->tree));
 }
 
+/**
+ * brasero_track_data_cfg_get_available_media:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Gets a list of all the media that can be appended with new data and which have a session that can be loaded.
+ *
+ * Return value: a #GSList of #BraseroMedium. Free the list and unref its contents when the list is not needed anymore.
+ **/
+
 GSList *
 brasero_track_data_cfg_get_available_media (BraseroTrackDataCfg *track)
 {
@@ -2077,6 +2241,14 @@ brasero_track_data_cfg_set_source (BraseroTrackData *track,
 							    grafts,
 							    excluded);
 
+	/* Remember that we own the list grafts and excluded
+	 * so we have to free them ourselves. */
+	g_slist_foreach (grafts, (GFunc) brasero_graft_point_free, NULL);
+	g_slist_free (grafts);
+
+	g_slist_foreach (excluded, (GFunc) g_free, NULL);
+	g_slist_free (excluded);
+
 	if (!priv->loading)
 		return BRASERO_BURN_OK;
 
@@ -2147,26 +2319,6 @@ brasero_track_data_cfg_get_fs (BraseroTrackData *track)
 	return fs_type;
 }
 
-gboolean
-brasero_track_data_cfg_get_contents (BraseroTrackData *track,
-				     GSList **grafts,
-				     GSList **excluded)
-{
-	BraseroTrackDataCfgPrivate *priv;
-
-	g_return_val_if_fail (BRASERO_IS_TRACK_DATA_CFG (track), FALSE);
-	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
-
-	/* append a slash for mkisofs */
-	brasero_data_project_get_contents (BRASERO_DATA_PROJECT (priv->tree),
-					   grafts,
-					   excluded,
-					   FALSE,	/* no hidden node */
-					   FALSE,	/* no grafts for joliet incompatible nodes */
-					   FALSE);	/* no final slash for names */
-	return TRUE;
-}
-
 static GSList *
 brasero_track_data_cfg_get_grafts (BraseroTrackData *track)
 {
@@ -2276,8 +2428,7 @@ brasero_track_data_cfg_get_status (BraseroTrack *track,
 		return BRASERO_BURN_ERR;
 	}
 
-	if (brasero_data_session_get_loaded_medium (BRASERO_DATA_SESSION (priv->tree)) == NULL
-	&& brasero_data_project_is_empty (BRASERO_DATA_PROJECT (priv->tree))) {
+	if (brasero_data_project_is_empty (BRASERO_DATA_PROJECT (priv->tree))) {
 		if (status)
 			brasero_status_set_error (status,
 						  g_error_new (BRASERO_BURN_ERROR,
@@ -2498,7 +2649,7 @@ brasero_track_data_cfg_find_icon_name (BraseroTrackDataCfg *track)
 	root = brasero_data_project_get_root (BRASERO_DATA_PROJECT (priv->tree));
 	do {
 		g_free (name);
-		name = g_strdup_printf ("Autorun%i.ico", i);
+		name = g_strdup_printf ("Autorun%i.ico", i++);
 	} while (brasero_file_node_check_name_existence (root, name));
 
 	return name;
@@ -2574,7 +2725,8 @@ brasero_track_data_cfg_name_collision_cb (BraseroDataProject *project,
 
 		return FALSE;
 	}
-	else if (node == priv->icon) {
+
+	if (node == priv->icon) {
 		gchar *uri;
 		gchar *name = NULL;
 		BraseroFileNode *root;
@@ -2766,6 +2918,22 @@ brasero_track_data_cfg_session_loaded_cb (BraseroDataSession *session,
 	brasero_track_changed (BRASERO_TRACK (self));
 }
 
+/**
+ * brasero_track_data_cfg_span:
+ * @track: a #BraseroTrackDataCfg
+ * @sectors: a #goffset
+ * @new_track: a #BraseroTrackData
+ *
+ * Creates a new #BraseroTrackData (stored in @new_track) from the files contained in @track. The sum of their sizes
+ * does not exceed @sectors. This allows to burn a tree on multiple discs. This function can be
+ * called repeatedly; in this case if some files were left out after the previous calls, the newly created BraseroTrackData
+ * is created with all or part of the remaining files.
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if there is not anymore data.
+ * BRASERO_BURN_RETRY if the operation was successful and a new #BraseroTrackDataCfg was created.
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_cfg_span (BraseroTrackDataCfg *track,
 			     goffset sectors,
@@ -2792,6 +2960,17 @@ brasero_track_data_cfg_span (BraseroTrackDataCfg *track,
 	return BRASERO_BURN_RETRY;
 }
 
+/**
+ * brasero_track_data_cfg_span_again:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Checks whether some files were not included during calls to brasero_track_data_cfg_span ().
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if there is not anymore data.
+ * BRASERO_BURN_RETRY if the operation was successful and a new #BraseroTrackDataCfg was created.
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_cfg_span_again (BraseroTrackDataCfg *track)
 {
@@ -2801,6 +2980,19 @@ brasero_track_data_cfg_span_again (BraseroTrackDataCfg *track)
 	return brasero_data_project_span_again (BRASERO_DATA_PROJECT (priv->tree));
 }
 
+/**
+ * brasero_track_data_cfg_span_possible:
+ * @track: a #BraseroTrackDataCfg
+ * @sectors: a #goffset
+ *
+ * Checks if a new #BraseroTrackData can be created from the files remaining in the tree 
+ * after calls to brasero_track_data_cfg_span ().
+ *
+ * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if there is not anymore data.
+ * BRASERO_BURN_RETRY if the operation was successful and a new #BraseroTrackDataCfg was created.
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_cfg_span_possible (BraseroTrackDataCfg *track,
 				      goffset sectors)
@@ -2817,6 +3009,13 @@ brasero_track_data_cfg_span_possible (BraseroTrackDataCfg *track,
 						   sectors);
 }
 
+/**
+ * brasero_track_data_cfg_span_stop:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Resets the list of files that were included after calls to brasero_track_data_cfg_span ().
+ **/
+
 void
 brasero_track_data_cfg_span_stop (BraseroTrackDataCfg *track)
 {
@@ -2826,11 +3025,43 @@ brasero_track_data_cfg_span_stop (BraseroTrackDataCfg *track)
 	brasero_data_project_span_stop (BRASERO_DATA_PROJECT (priv->tree));
 }
 
+/**
+ * brasero_track_data_cfg_span_max_space:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Returns the maximum required space (in sectors) 
+ * among all the possible spanned batches.
+ * This means that when burningto a media
+ * it will also be the minimum required
+ * space to burn all the contents in several
+ * batches.
+ *
+ * Return value: a #goffset.
+ **/
+
+goffset
+brasero_track_data_cfg_span_max_space (BraseroTrackDataCfg *track)
+{
+	BraseroTrackDataCfgPrivate *priv;
+
+	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
+	return brasero_data_project_get_max_space (BRASERO_DATA_PROJECT (priv->tree));
+}
+
 /**
  * This is to handle the icon for the image
  */
 
-const gchar *
+/**
+ * brasero_track_data_cfg_get_icon_path:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Returns a path pointing to the currently selected icon file.
+ *
+ * Return value: a #gchar or NULL.
+ **/
+
+gchar *
 brasero_track_data_cfg_get_icon_path (BraseroTrackDataCfg *track)
 {
 	BraseroTrackDataCfgPrivate *priv;
@@ -2838,7 +3069,40 @@ brasero_track_data_cfg_get_icon_path (BraseroTrackDataCfg *track)
 	g_return_val_if_fail (BRASERO_IS_TRACK_DATA_CFG (track), NULL);
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
-	return priv->image_path;
+	if (!priv->image_file)
+		return NULL;
+
+	return g_file_get_path (priv->image_file);
+}
+
+/**
+ * brasero_track_data_cfg_get_icon:
+ * @track: a #BraseroTrackDataCfg
+ *
+ * Returns the currently selected icon.
+ *
+ * Return value: a #GIcon or NULL.
+ **/
+
+GIcon *
+brasero_track_data_cfg_get_icon (BraseroTrackDataCfg *track)
+{
+	gchar *array [] = {"media-optical", NULL};
+	BraseroTrackDataCfgPrivate *priv;
+	BraseroMedium *medium;
+	GIcon *icon;
+
+	g_return_val_if_fail (BRASERO_IS_TRACK_DATA_CFG (track), NULL);
+
+	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
+	if (priv->image_file)
+		icon = g_file_icon_new (priv->image_file);
+	else if ((medium = brasero_data_session_get_loaded_medium (BRASERO_DATA_SESSION (priv->tree))))
+		icon = brasero_volume_get_icon (BRASERO_VOLUME (medium));
+	else
+		icon = g_themed_icon_new_from_names (array, -1);
+
+	return icon;
 }
 
 static gchar *
@@ -2860,6 +3124,17 @@ brasero_track_data_cfg_get_scaled_icon_path (BraseroTrackDataCfg *track)
 	return path;
 }
 
+/**
+ * brasero_track_data_cfg_set_icon:
+ * @track: a #BraseroTrackDataCfg
+ * @icon_path: a #gchar
+ * @error: a #GError
+ *
+ * Sets the current icon.
+ *
+ * Return value: a #gboolean. TRUE if the operation was successful, FALSE otherwise
+ **/
+
 gboolean
 brasero_track_data_cfg_set_icon (BraseroTrackDataCfg *track,
 				 const gchar *icon_path,
@@ -2879,12 +3154,18 @@ brasero_track_data_cfg_set_icon (BraseroTrackDataCfg *track,
 	root = brasero_data_project_get_root (BRASERO_DATA_PROJECT (priv->tree));
 
 	if (!priv->autorun) {
-		if (brasero_file_node_check_name_existence_case (root, "autorun.inf")) {
+		BraseroFileNode *node;
+
+		node = brasero_file_node_check_name_existence_case (root, "autorun.inf");
+		if (node && !node->is_imported) {
 			/* There is a native autorun.inf file. That's why we can't edit
 			 * it; even if we were to create a temporary file with just the
 			 * icon changed then we could not save it as a project later.
 			 * If I change my mind, I should remember that it the path is
-			 * the value ON DISC. */
+			 * the value ON DISC.
+			 * The only exception is if the autorun.inf is an autorun.inf
+			 * that was imported from another session when we're 
+			 * merging. */
 			return FALSE;
 		}
 	}
@@ -2996,7 +3277,12 @@ brasero_track_data_cfg_set_icon (BraseroTrackDataCfg *track,
 		brasero_track_data_cfg_autorun_inf_update (track);
 	}
 
-	priv->image_path = g_strdup (icon_path);
+	if (priv->image_file) {
+		g_object_unref (priv->image_file);
+		priv->image_file = NULL;
+	}
+
+	priv->image_file = g_file_new_for_path (icon_path);
 	g_signal_emit (track,
 		       brasero_track_data_cfg_signals [ICON_CHANGED],
 		       0);
@@ -3095,6 +3381,88 @@ brasero_track_data_cfg_init (BraseroTrackDataCfg *object)
 			  object);
 }
 
+static void
+brasero_track_data_cfg_finalize (GObject *object)
+{
+	BraseroTrackDataCfgPrivate *priv;
+
+	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (object);
+
+	brasero_track_data_clean_autorun (BRASERO_TRACK_DATA_CFG (object));
+	brasero_track_data_cfg_clean_cache (BRASERO_TRACK_DATA_CFG (object));
+
+	if (priv->shown) {
+		g_slist_free (priv->shown);
+		priv->shown = NULL;
+	}
+
+	if (priv->tree) {
+		/* This object could outlive us just for some time
+		 * so we better remove all signals.
+		 * When an image URI is detected it can happen
+		 * that we'll be destroyed. */
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_node_added,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_node_changed,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_node_removed,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_node_reordered,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_size_changed_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_session_available_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_session_loaded_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_project_loaded,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_activity_changed,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_deep_directory,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_2G_file,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_unreadable_uri_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_unknown_uri_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_recursive_uri_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_image_uri_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_virtual_sibling_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_name_collision_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->tree,
+		                                      brasero_track_data_cfg_joliet_rename_cb,
+		                                      object);
+
+		g_object_unref (priv->tree);
+		priv->tree = NULL;
+	}
+
+	G_OBJECT_CLASS (brasero_track_data_cfg_parent_class)->finalize (object);
+}
+
 static void
 brasero_track_data_cfg_class_init (BraseroTrackDataCfgClass *klass)
 {
@@ -3260,6 +3628,14 @@ brasero_track_data_cfg_class_init (BraseroTrackDataCfgClass *klass)
 			  G_TYPE_NONE);
 }
 
+/**
+ * brasero_track_data_cfg_new:
+ *
+ * Creates a new #BraseroTrackDataCfg.
+ *
+ * Return value: a new #BraseroTrackDataCfg.
+ **/
+
 BraseroTrackDataCfg *
 brasero_track_data_cfg_new (void)
 {
