@@ -87,6 +87,8 @@ struct _BraseroMediumPrivate
 	GThread *probe;
 	GMutex *mutex;
 	GCond *cond;
+	GCond *cond_probe;
+
 	gint probe_id;
 
 	GSList *tracks;
@@ -2953,6 +2955,7 @@ static gpointer
 brasero_medium_probe_thread (gpointer self)
 {
 	gint counter = 0;
+	GTimeVal wait_time;
 	const gchar *device;
 	BraseroScsiErrCode code;
 	BraseroMediumPrivate *priv;
@@ -2978,43 +2981,56 @@ brasero_medium_probe_thread (gpointer self)
 		handle = brasero_device_handle_open (device, FALSE, &code);
 	}
 
-	if (priv->probe_cancelled)
+	if (!handle) {
+		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
 		goto end;
+	}
 
-	if (handle) {
-		BRASERO_MEDIA_LOG ("Open () succeeded");
+	if (priv->probe_cancelled) {
+		brasero_device_handle_close (handle);
+		goto end;
+	}
 
-		/* NOTE: if we wanted to know the status we'd need to read the 
-		 * error code variable which is currently NULL */
-		while (brasero_spc1_test_unit_ready (handle, &code) != BRASERO_SCSI_OK) {
-			if (code == BRASERO_SCSI_NO_MEDIUM) {
-				brasero_device_handle_close (handle);
-				BRASERO_MEDIA_LOG ("No medium inserted");
-				priv->info = BRASERO_MEDIUM_NONE;
-				goto end;
-			}
-			else if (code != BRASERO_SCSI_NOT_READY) {
-				brasero_device_handle_close (handle);
-				BRASERO_MEDIA_LOG ("Device does not respond");
-				goto end;
-			}
+	BRASERO_MEDIA_LOG ("Open () succeeded");
 
-			sleep (2);
+	/* NOTE: if we wanted to know the status we'd need to read the 
+	 * error code variable which is currently NULL */
+	while (brasero_spc1_test_unit_ready (handle, &code) != BRASERO_SCSI_OK) {
+		if (code == BRASERO_SCSI_NO_MEDIUM) {
+			BRASERO_MEDIA_LOG ("No medium inserted");
+			priv->info = BRASERO_MEDIUM_NONE;
 
-			if (priv->probe_cancelled) {
-				brasero_device_handle_close (handle);
-				BRASERO_MEDIA_LOG ("Device probing cancelled");
-				goto end;
-			}
+			brasero_device_handle_close (handle);
+			goto end;
+		}
+		else if (code != BRASERO_SCSI_NOT_READY) {
+			BRASERO_MEDIA_LOG ("Device does not respond");
+
+			brasero_device_handle_close (handle);
+			goto end;
 		}
 
-		BRASERO_MEDIA_LOG ("Device ready");
+		g_get_current_time (&wait_time);
+		g_time_val_add (&wait_time, 2000000);
 
-		brasero_medium_init_real (BRASERO_MEDIUM (self), handle);
-		brasero_device_handle_close (handle);
+		g_mutex_lock (priv->mutex);
+		g_cond_timed_wait (priv->cond_probe,
+		                   priv->mutex,
+		                   &wait_time);
+		g_mutex_unlock (priv->mutex);
+
+		if (priv->probe_cancelled) {
+			BRASERO_MEDIA_LOG ("Device probing cancelled");
+
+			brasero_device_handle_close (handle);
+			goto end;
+		}
 	}
-	else
-		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
+
+	BRASERO_MEDIA_LOG ("Device ready");
+
+	brasero_medium_init_real (BRASERO_MEDIUM (self), handle);
+	brasero_device_handle_close (handle);
 
 end:
 
@@ -3072,6 +3088,7 @@ brasero_medium_init (BraseroMedium *object)
 
 	priv->mutex = g_mutex_new ();
 	priv->cond = g_cond_new ();
+	priv->cond_probe = g_cond_new ();
 
 	/* we can't do anything here since properties haven't been set yet */
 }
@@ -3087,7 +3104,15 @@ brasero_medium_finalize (GObject *object)
 
 	g_mutex_lock (priv->mutex);
 	if (priv->probe) {
+		/* This to signal that we are cancelling */
 		priv->probe_cancelled = TRUE;
+
+		/* This is to wake up the thread if it
+		 * was asleep waiting to retry to get
+		 * hold of a handle to probe the drive */
+		g_cond_signal (priv->cond_probe);
+
+		/* Wait for the end of the thread */
 		g_cond_wait (priv->cond, priv->mutex);
 	}
 	g_mutex_unlock (priv->mutex);
@@ -3107,6 +3132,11 @@ brasero_medium_finalize (GObject *object)
 		priv->cond = NULL;
 	}
 
+	if (priv->cond_probe) {
+		g_cond_free (priv->cond_probe);
+		priv->cond_probe = NULL;
+	}
+
 	if (priv->id) {
 		g_free (priv->id);
 		priv->id = NULL;
@@ -3285,7 +3315,7 @@ brasero_medium_can_be_rewritten (BraseroMedium *medium)
 	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVDRW_PLUS_DL)
 	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVD_RAM)
 	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_BDRE))
-		return priv->write_command != 0;
+		return TRUE;
 
 	return FALSE;
 }
